==> Repetier-Server-Frontend-0.86.2.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/params.component.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component} from '@angular/core';
import {RSUIHelper} from "@repetier/front-ui";
import {PrinterState, PrintersState, PrinterAction} from "@repetier/binding";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-params-component',
    template: `
      <rs-page>
        <side>
          <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
        </side>
        <side>
          <rs-sideicon *ngIf="printer?.printing" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        </side>
        <side>
          <rs-sideicon title="<?php _('Temp.') ?>" icon="rs rs-chart" link="/temperatures"></rs-sideicon>
        </side>
        <main>
          <h1><?php _('Printer Status') ?></h1>
          <div class="content-h1 iconlist" style="padding: 0;" *ngIf="printer" rs-drag>

            <div class="button-icon sep-icon" *ngFor="let p of printer.extruders;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setExtruderTemp(idx)">
                <i class="rs rs-extruder fw"></i>
                <div class="multiline">
                  <span [class.strong]="idx==printer.activeExtruderId">{{printerAction.extruderName(printer.slug, idx)}}</span><br>
                  {{p.currentTemp | fixed:1}} | {{p.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>

            <div class="button-icon sep-icon" *ngIf="printer.config.heatedBed?.installed">
              <rs-button class="secondary outline full" (hit)="ui.setBedTemp()">
                <i class="rs rs-heated-bed fw"></i>
                <div class="multiline"><?php _('Bed') ?><br>
                  {{printer.heatedBed.currentTemp | fixed:1}} | {{printer.heatedBed.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer.config.heatedChamber?.installed">
              <rs-button class="secondary outline full" (hit)="ui.setChamberTemp()">
                <i class="rs rs-chamber fw"></i>
                <div class="multiline"><?php _('Chamber') ?><br>
                  {{printer.heatedChamber.currentTemp | fixed:1}} | {{printer.heatedChamber.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer.config.general?.fan">
              <rs-button class="secondary outline full" (hit)="ui.setFan()">
                <i class="rs rs-fan fw"></i>
                <div class="multiline"><?php _('Fan') ?><br>
                  <div *ngIf="printer.fanOn">{{printer.fanPercent | fixed:0}}%</div>
                  <div *ngIf="!printer.fanOn"><?php _('Off') ?></div>
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer.config.general?.fan2">
              <rs-button class="secondary outline full" (hit)="ui.setFan2()">
                <i class="rs rs-fan fw"></i>
                <div class="multiline"><?php _('Fan') ?> 2<br>
                  <div *ngIf="printer.fan2On">{{printer.fan2Percent | fixed:0}}%</div>
                  <div *ngIf="!printer.fan2On"><?php _('Off') ?></div>
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setSpeed()">
                <i class="rs rs-speed fw"></i>
                <div class="multiline"><?php _('Speed') ?><br>
                  {{printer.speedMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setFlow()">
                <i class="rs rs-flow fw"></i>
                <div class="multiline"><?php _('Flow') ?><br>
                  {{printer.flowMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.toggleCaseLights(printer.slug)">
                <i class="rs rs-light fw"></i> <?php _('Light On/Off') ?> </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer?.config?.general?.softwarePower">
              <rs-button class="secondary outline full" (hit)="printerAction.power(printer.slug)">
                <i class="fa fa-power-off fw"></i> <?php _('Power On/Off') ?>&nbsp;
              </rs-button>
            </div>
          </div>
        </main>
      </rs-page>
    `
})

export class ParamsComponent {
    printer: PrinterState;
    @select('printers') printers$: Observable<PrintersState>;

    private printersSubscription: ISubscription;

    constructor(public ui: RSUIHelper, private printerAction: PrinterAction) {
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                this.printer = p.printers[p.active];
            } else this.printer = undefined;
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
    }

}

==> Repetier-Server-Frontend-0.90.1.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/params.component.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component} from '@angular/core';
import {RSUIHelper} from "@repetier/front-ui";
import {PrinterState, PrintersState, PrinterAction} from "@repetier/binding";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-params-component',
    template: `
      <rs-page>
        <side>
          <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
        </side>
        <side>
          <rs-sideicon *ngIf="printer?.printing" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        </side>
        <side>
          <rs-sideicon title="<?php _('Temp.') ?>" icon="rs rs-chart" link="/temperatures"></rs-sideicon>
        </side>
        <main>
          <h1><?php _('Printer Status') ?></h1>
          <div class="content-h1 iconlist" style="padding: 0;" *ngIf="printer" rs-drag>

            <div class="button-icon sep-icon" *ngFor="let p of printer.extruders;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setExtruderTemp(idx)">
                <i class="rs rs-extruder fw"></i>
                <div class="multiline">
                  <span [class.strong]="idx==printer.activeExtruderId">{{printerAction.extruderName(printer.slug, idx)}}</span><br>
                  {{p.currentTemp | fixed:1}} | {{p.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>

            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedBeds;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setBedTemp(idx)">
                <i class="rs rs-heated-bed fw"></i>
                <div class="multiline"><?php _('Bed') ?><br>
                  {{p.currentTemp | fixed:1}} | {{p.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedChambers;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setChamberTemp(idx)">
                <i class="rs rs-chamber fw"></i>
                <div class="multiline"><?php _('Chamber') ?><br>
                  {{p.currentTemp | fixed:1}} | {{p.tempSet | fixed:0}}°C
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.fans;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setFan(idx)">
                <i class="rs rs-fan fw"></i>
                <div class="multiline"><?php _('Fan') ?> {{idx+1}}<br>
                  <div *ngIf="p.on">{{p.percent | fixed:0}}%</div>
                  <div *ngIf="!p.on"><?php _('Off') ?></div>
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setSpeed()">
                <i class="rs rs-speed fw"></i>
                <div class="multiline"><?php _('Speed') ?><br>
                  {{printer.speedMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setFlow()">
                <i class="rs rs-flow fw"></i>
                <div class="multiline"><?php _('Flow') ?><br>
                  {{printer.flowMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.toggleCaseLights(printer.slug)">
                <i class="rs rs-light fw"></i> <?php _('Light On/Off') ?> </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer?.config?.general?.softwarePower">
              <rs-button class="secondary outline full" (hit)="printerAction.power(printer.slug)">
                <i class="fa fa-power-off fw"></i> <?php _('Power On/Off') ?>&nbsp;
              </rs-button>
            </div>
          </div>
        </main>
      </rs-page>
    `
})

export class ParamsComponent {
    printer: PrinterState;
    @select('printers') printers$: Observable<PrintersState>;

    private printersSubscription: ISubscription;

    constructor(public ui: RSUIHelper, private printerAction: PrinterAction) {
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                this.printer = p.printers[p.active];
            } else this.printer = undefined;
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
    }

}
